--- predict.c.orig	2024-10-18 10:00:59.000000000 +0200
+++ predict.c	2024-10-18 10:01:57.000000000 +0200
@@ -35,8 +35,60 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <termios.h>
+#include <arpa/inet.h>
+#include <unistd.h>
 #include "predict.h"
 
+int send_frequency_to_rigctl(double downlink, double dopp, const char *ip_address, int port) {
+    int sockfd;
+    struct sockaddr_in servaddr;
+    char buffer[256];
+    long long int predfreq;
+
+    // Calculate the frequency
+    predfreq = (long long int)((downlink + dopp) * 1000000); // Convert MHz to Hz
+
+    // Create socket
+    if ((sockfd = socket(AF_INET, SOCK_STREAM, 0)) < 0) {
+        perror("Socket creation failed");
+        return -1;
+    }
+
+    // Configure the server address
+    memset(&servaddr, 0, sizeof(servaddr));
+    servaddr.sin_family = AF_INET;
+    servaddr.sin_port = htons(port);
+
+    // Convert IP address to binary format and assign to servaddr
+    if (inet_pton(AF_INET, ip_address, &servaddr.sin_addr) <= 0) {
+        perror("Invalid address or address not supported");
+        close(sockfd);
+        return -1;
+    }
+
+    // Connect to the RigCtl server
+    if (connect(sockfd, (struct sockaddr*)&servaddr, sizeof(servaddr)) < 0) {
+        perror("Connection to RigCtl server failed");
+        close(sockfd);
+        return -1;
+    }
+
+    // Format the frequency command (e.g., "f 145500000\n")
+    snprintf(buffer, sizeof(buffer), "F %lld\n", predfreq);
+
+    // Send the command to the RigCtl server
+    if (send(sockfd, buffer, strlen(buffer), 0) < 0) {
+        perror("Failed to send frequency to RigCtl server");
+        close(sockfd);
+        return -1;
+    }
+
+    // Close the socket after sending the command
+    close(sockfd);
+    return 0;
+}
+
+
 #if defined __has_include
   #if __has_include(<alsa/asoundlib.h>)
 	#include <alsa/asoundlib.h>
@@ -5830,6 +5882,7 @@
 					loss=32.4+(20.0*log10(downlink))+(20.0*log10(sat_range));
 					mvprintw(13,67,"%7.3f dB",loss);
 					mvprintw(14,13,"%7.3f   ms",delay);
+					send_frequency_to_rigctl(downlink, dopp, "10.0.0.52", 4532);
 				}
 
 				else
